/*
	Sample Worklist query, based on pixelmed.jar and hnetworklist.jar

	------------------------------------------------
	(C) 2009 Ing. Bro Kleiber, 8142 Uitikon-Waldegg
	------------------------------------------------

	27/11/2009/mkl

	Redistribution and use in source and binary forms, with or without modification, are
	permitted provided that the following conditions are met:
 
	1. Redistributions of source code must retain the above copyright notice, this list of
	   conditions and the following disclaimers.
 
	2. Redistributions in binary form must reproduce the above copyright notice, this list of
	   conditions and the following disclaimers in the documentation and/or other materials
	   provided with the distribution.
 
	3. Neither the name of PixelMed Publishing nor the names of its contributors, including
	   Ing. Buero Kleiber, may be used to endorse or promote products derived from this software.
 
	This software is provided by the copyright holders and contributors "as is" and any
	express or implied warranties, including, but not limited to, the implied warranties
	of merchantability and fitness for a particular purpose are disclaimed. In no event
	shall the copyright owner or contributors be liable for any direct, indirect, incidental,
	special, exemplary, or consequential damages (including, but not limited to, procurement
	of substitute goods or services; loss of use, data or profits; or business interruption)
	however caused and on any theory of liability, whether in contract, strict liability, or
	tort (including negligence or otherwise) arising in any way out of the use of this software,
	even if advised of the possibility of such damage.
 
	This software has neither been tested nor approved for clinical use or for incorporation in
	a medical device. It is the redistributor's or user's responsibility to comply with any
	applicable local, state, national or international regulations.

*/

import ch.hnet.dicom.worklist.WorkListEntry;
import ch.hnet.dicom.worklist.MWLScu;


public class WorklistQuery {

	public static void main(String[] args) throws Exception {

		// initialize SCU to local dcmtk worklist server
		MWLScu mwlscu = new MWLScu("localhost", 1234, "Store1", "HnetMWLScu", false);

		// set query arguments
		mwlscu.setPatientName("VIVALDI*");	// patient name wildcard
		mwlscu.setModality("CT");

		// perform the query
		int n = mwlscu.cFind();

		// eval results
		if(n > 0){
			System.err.println("" + n + " matching Worklist Entries found");

			WorkListEntry[] wL = mwlscu.getResult();

			for(int i = 0; i < n; i++){

				WorkListEntry wl = wL[i];
				System.err.println("============ #" + (i+1) + " ================");
				System.err.println("Patient is          " + wl.getPatientName());
				System.err.println("PatientID is        " + wl.getPatientID());
				System.err.println("PatientSex is       " + wl.getPatientSex());
				System.err.println("Modality is         " + wl.getModality());
				System.err.println("AccessionNo is      " + wl.getAccessionNumber());
				System.err.println("StudyInstanceUid is " + wl.getStudyInstanceUid());
				System.err.println("ProcStepStatus is   " + wl.getScheduledProcedureStepStatus());

			}
		}
		else{
			System.err.println("No matching Worklist Entries found");
		}
	}
}